︠eedd846f-e8fa-4be5-9cd9-6755caee5f07i︠
%md
# Using the CubicBraidGroup class
## Introduction



This module is devoted to factor groups of the Artin braid groups, such that the images $s_i$ of the braid generators
have order three:

$$ s_i^3 = 1 $$

In general these groups have firstly been investigated by Coxeter, H.S.M in: "Factor groups of the braid groups, Proceedings of the Fourth Candian Mathematical Congress (Vancover 1957), pp. 95-122".

Coxeter showed, that these groups are finite as long as the number of strands is less than 6 and infinite elsewise. More explicitely the factor group on three strand braids is isomorphic to $SL(2,3)$, on four strand braids to $GU(3,2)$ and on five strand braids to $Sp(4,3) \times C_3$. Coxeter realized these groups as subgroups of unitary groups with respect to a certain hermitian form over the complex numbers (in fact over $\QQ$ adjoined with a primitive 12-th root of unity).

In "Einige endliche Faktorgruppen der Zopfgruppen" (Math. Z., 163 (1978), 291-302) J. Assion considered two series $S(m)$ and $U(m)$ of finite dimensional factors of these groups. The additional relations on the braid group generators $\{ s_1, \cdots , s_{m-1}\}$ are


$$ \begin{array}{rllll}
s_3 s_1 t_2 s_1 t_2^{-1} t_3 t_2 s_1 t_2^{-1} t_3^{-1} = 1 & \mbox{ for } & m >= 5 & \mbox{ in case of}  & S(m) \\
t_1 t_3 = 1          &    \mbox{ for }  & m >= 5 & \mbox{ in case of } & U(m)
\end{array} $$


where $t_i = (s_i s_{i+1})^3$. He showed that each series of finite cubic braid group factors must be an epimorphic image of one of his two series, as long as the groups with less than 5 strands are the full cubic braid groups, whereas the group on 5 strands is not. He realized the groups $S(m)$ as symplectic groups over $GF(3)$ (resp. subgroups therein) and $U(m)$ as general unitary groups over $GF(4)$ (resp. subgroups therein).

This class implements all the groups conidered by Coxeter and Assion as finitely presented groups (via the gap interface) together with the classical realizations given by the authors. It also contains the coercion maps between the two ways of
realization. In addition the user can construct other realizations and maps to matrix groups with help of the burau representation. In case gap3 and CHEVIE are installed under sage version 7.2 (or later) the reflection groups via the gap3
interface are availlable, too. The methods for all this functionality are:

   - as_classical_group
   - as_matrix_group
   - as_reflection_group    (needs sage version 7.2 up and gap3 + CHEVIE)
   - as_permutation_group

Further methods are:

   - order 
   - pre_image_braid_group
   - cubic_braid_subgroup
   - character_table

AUTHOR

   Sebastian Oehms, Sept. 2016
︡3701b8c8-a654-49db-9444-baded38da0c0︡{"done":true,"md":"# Using the CubicBraidGroup class\n## Introduction\n\n\n\nThis module is devoted to factor groups of the Artin braid groups, such that the images $s_i$ of the braid generators\nhave order three:\n\n$$ s_i^3 = 1 $$\n\nIn general these groups have firstly been investigated by Coxeter, H.S.M in: \"Factor groups of the braid groups, Proceedings of the Fourth Candian Mathematical Congress (Vancover 1957), pp. 95-122\".\n\nCoxeter showed, that these groups are finite as long as the number of strands is less than 6 and infinite elsewise. More explicitely the factor group on three strand braids is isomorphic to $SL(2,3)$, on four strand braids to $GU(3,2)$ and on five strand braids to $Sp(4,3) \\times C_3$. Coxeter realized these groups as subgroups of unitary groups with respect to a certain hermitian form over the complex numbers (in fact over $\\QQ$ adjoined with a primitive 12-th root of unity).\n\nIn \"Einige endliche Faktorgruppen der Zopfgruppen\" (Math. Z., 163 (1978), 291-302) J. Assion considered two series $S(m)$ and $U(m)$ of finite dimensional factors of these groups. The additional relations on the braid group generators $\\{ s_1, \\cdots , s_{m-1}\\}$ are\n\n\n$$ \\begin{array}{rllll}\ns_3 s_1 t_2 s_1 t_2^{-1} t_3 t_2 s_1 t_2^{-1} t_3^{-1} = 1 & \\mbox{ for } & m >= 5 & \\mbox{ in case of}  & S(m) \\\\\nt_1 t_3 = 1          &    \\mbox{ for }  & m >= 5 & \\mbox{ in case of } & U(m)\n\\end{array} $$\n\n\nwhere $t_i = (s_i s_{i+1})^3$. He showed that each series of finite cubic braid group factors must be an epimorhic image of one of his two series, as long as the groups with less than 5 strands are the full cubic braid groups, whereas the group on 5 strands is not. He realized the groups $S(m)$ as symplectic groups over $GF(3)$ (resp. subgroups therein) and $U(m)$ as general unitary groups over $GF(4)$ (resp. subgroups therein).\n\nThis class implements all the groups conidered by Coxeter and Assion as finitely presented groups (via the gap interface) together with the classical realizations given by the authors. It also contains the coercion maps between the two ways of\nrealization. In addition the user can construct other realizations and maps to matrix groups with help of the burau representation. In case gap3 and CHEVIE are installed under sage version 7.2 (or later) the reflection groups via the gap3\ninterface are availlable, too. The methods for all this functionality are:\n\n   - as_classical_group\n   - as_matrix_group\n   - as_reflection_group    (needs sage version 7.2 up and gap3 + CHEVIE)\n   - as_permutation_group\n\nFurther methods are:\n\n   - order \n   - pre_image_braid_group\n   - cubic_braid_subgroup\n   - character_table\n\nAUTHOR\n\n   Sebastian Oehms, Sept. 2016"}
︠1d8eb7a4-5962-4db0-b7e3-3bec8423e297i︠
%md
## Getting started
The CubicBraidGroup class is not integrated into the sage library, right now. If you are using sage on your own computer you may install the CubicBraidGoup class following the README.txt file.
To use the CubicBraidGroup on this plattform you can create a jupyter notebook or a sage worksheet (like this) and start with a cell containing the first line of this:
︡53b8aa2f-287f-4199-b021-79943dad80b9︡{"done":true,"md":"## Getting started\nThe CubicBraidGroup class is not integrated into the sage library, right now. If you are using sage on your own computer you may install the CubicBraidGoup class following the README.txt file.\nTo use the CubicBraidGroup on this plattform you can create a jupyter notebook or a sage worksheet (like this) and start with a cell containing the first line of this:"}
︠0c732741-8c47-4e40-825f-37ae7261244as︠
%auto
from cubic_braid import *
︡6821db4b-39f0-4c4f-9c3e-c82eee52a678︡{"done":true}︡
︠d5648cb4-f34d-426d-87f0-b0758cc63322i︠
%md
To execute the command you must click on the "play" symbol (>|) above (instead of carriage return key in a shell session)

On your own computer in a command-line sage-session you must start with this line, as well. For further information on how to get started see the README.txt-File.

The general documentation concerning the CubicBraidGroup class can be shown using the following command.
︡d09ed6a6-9495-4aef-8d1f-890ba7de63aa︡{"done":true,"md":"To execute the command you must click on the \"play\" symbol (>|) above (instead of carriage return key in a shell session)\n\nOn your own computer in a command-line sage-session you must start with this line, as well. For further information on how to get started see the README.txt-File.\n\nThe general documentation concerning the CubicBraidGroup class can be shown using the following command."}
︠6fcaa2ab-0fb1-4345-bcc7-c26d9a6d86dbs︠
print CubicBraidGroup_class.__doc__
︡9fa2a50e-9d60-4751-a501-71975afe96a8︡{"stdout":"\n    Class to handel cubic factors of braid group on n strands\n\n    If you don't see this well formatted type \n\n    sage: print CubicBraidGroup_class.__doc__\n\n    This class implements quotient groups of the braid group mapping their generators to elements of order 3 \n    (see the module header for more informations on these groups)\n\n    These groups are implemented as a particular case of finitely presented groups similar to the BraidGroup class \n\n    A cubic braid group can be created by giving the number of strands, and the name of the generators in a similar \n    way as it works for the BraidGroup class. \n \n    INPUT (to the constructor):\n    \n    - \"names\": (see the BraidGroup_class docomentation)\n\n    - \"AdditionalRelation\": (keyword, explantaion see below)\n\n    - \"verbose\": (keyword, explantaion see below)\n\n\n    RAISE (on init):\n\n      - ValueError: \"the number of strands must be an integer larger than one\"\n\n\n    Setting the keyword 'AdditionalRelation' to one on the values 'S' or 'U' the additional relations due to \n    Assion are added:\n\n     'S': $s_3 s_1 t_2 s_1 t_2^{-1} t_3 t_2 s_1 t_2^{-1} t_3^{-1) = 1$ for $m >= 5$  \n     'U': $t_1 t_3 = 1$                                                for $m >= 5$  \n\n\n    where $t_i = (s_i s_{i+1})^3$. If AdditionalRelation='C' (default) only the cubic relation on the generators is \n    active (Coxeters case of investigation). Note that for n=2,3,4 the groups do not differ between the three possible\n    values of AdditionalRelation (as finitely presented groups). But anyway, the classes for 'C', 'S' and 'U' are \n    different, since they have different classical realizations implemented .\n\n    Setting the keyword verbose it is possible to print time stamp messages in order to do a performance or \n    call stack debugging. This keyword uses the timeStampControl class. For more information on this type\n\n                     print setupTimeStamp.__doc__\n                     print timeStampControl.__doc__\n                     print timeStampControl.print_timestamp.__doc__\n                     print print_time_tb.__doc__\n    \n\n    The creation of instances of this class can also be done more easy by help of the functions CubicBraidGroup, \n    AssionGroupS and AssionGroupU (similar to the function BraidGroup with respect to the BraidGroup_class)\n\n\n    EXAMPLES:\n\n        sage: from cubic_braid import *\n        sage: U3 = CubicBraidGroup(3, AdditionalRelation = 'U'); U3\n        Assion group on 3 strands of type U\n        sage: U3.gens()\n        (c0, c1)\n\n     alternate possibilities defining U3:\n\n        sage: U3 = AssionGroupU(3); U3\n        Assion group on 3 strands of type U\n        sage: U3.gens()\n        (u0, u1)\n\n        sage: U3.<u1,u2> = AssionGroupU(3); U3\n        Assion group on 3 strands of type U\n        sage: U3.gens()\n        (u1, u2)\n\n    alternates naming the generators:\n\n        sage: U3 = AssionGroupU(3, 'a, b'); U3\n        Assion group on 3 strands of type U\n        sage: U3.gens()\n        (a, b)\n\n        sage: C3 = CubicBraidGroup(3, 't'); C3\n        Cubic Braid group on 3 strands\n        sage: C3.gens()\n        (t0, t1)\n\n        sage: U3.is_isomorphic( C3 )\n        True\n        sage: U3.as_classical_group()\n        Subgroup of (The projective general unitary group of degree 3 over Finite Field of size 2) generated by\n        [(1,7,6) (3,19,14)(4,15,10)(5,11,18)(12,16,20), (1,12,13)(2,15,19)(4,9,14)(5,18,8)(6,21,16)]\n        sage: C3.as_classical_group()\n        Subgroup of General Unitary Group of degree 2 over Universal Cyclotomic Field with respect to hermitian form \n        [-E(12)^7 + E(12)^11                  -1]\n        [                 -1 -E(12)^7 + E(12)^11] \n        generated by (\n        [    E(3) E(12)^11]\n        [       0        1], \n        [       1        0]\n        [E(12)^11     E(3)])\n\n\n    using verbose mode:\n\n        sage: C3.<c1,c2> = CubicBraidGroup(3, verbose=True); C3\n        L: StackInfo    Elapse:     0, Total:   0 Ident: C3 In: __init__ Line: 403\n        L: StackInfo    Elapse:   197, Total:   0 Begin In: __create_classical_realization__ Line: 910\n        L: StackInfo    Elapse:     8, Total:   0 Begin In: as_matrix_group Line: 1031\n        L: Body         Elapse:    92, Total:   0 genList prepared In: as_matrix_group Line: 1038\n        L: Body         Elapse:    52, Total:   0 MatGroup defined In: as_matrix_group Line: 1054\n        L: StackInfo    Elapse:   356, Total:   0 Begin In: gap_hom Line: 143\n        L: Debug        Elapse:     8, Total:   0 GroupHomomorphis In: gap_hom Line: 188\n        L: Debug        Elapse:    17, Total:   0 checked if groupMap works In: gap_hom Line: 199\n        L: StackInfo    Elapse:     8, Total:   0 End In: gap_hom Line: 226\n        L: StackInfo    Elapse:    44, Total:   0 Begin In: __check_homomorphism__ Line: 60\n        L: StackInfo    Elapse:    52, Total:   0 End In: __check_homomorphism__ Line: 625\n        L: Body         Elapse:     3, Total:   0 Hom from self defined In: as_matrix_group Line: 1064\n        L: StackInfo    Elapse:    62, Total:   0 Begin In: gap_hom Line: 143\n        L: Debug        Elapse:     4, Total:   0 GroupHomomorphis In: gap_hom Line: 188\n        L: Debug        Elapse:    20, Total:   0 checked if groupMap works In: gap_hom Line: 199\n        L: StackInfo    Elapse:     4, Total:   0 End In: gap_hom Line: 226\n        L: Body         Elapse:    35, Total:   0 Section to self defined In: as_matrix_group Line: 1077\n        L: StackInfo    Elapse:     3, Total:   0 Ende In: as_matrix_group Line: 1102\n        L: StackInfo    Elapse:     3, Total:   0 End In: __create_classical_realization__ Line: 975\n        L: StackInfo    Elapse:    12, Total:   0 Ident: C3 In: __init__ Line: 472\n        Cubic Braid group on 3 strands\n        sage: \n        sage: \n        sage: C3.<c1,c2> = CubicBraidGroup(3, verbose=30); C3\n        L: StackInfo    Elapse:    62, Total:   0 (truncated   1) Begin In: __create_classical_realization__ Line: 910\n            ---> __init__ In: lib/cubic_braid.py Line: 471\n            ---> __classcall__ In: /opt/sage/sage-6.9-i686-Linux/local/lib/python2.7/site-packages/sage/structure\n        /unique_representation.py Line: 1021\n            ---> CubicBraidGroup In: lib/cubic_braid.py Line: 1231\n        L: StackInfo    Elapse:   405, Total:   0 Begin In: as_matrix_group Line: 1031\n            ---> __create_classical_realization__ In: lib/cubic_braid.py Line: 968\n            ---> __init__ In: lib/cubic_braid.py Line: 471\n            ---> __classcall__ In: /opt/sage/sage-6.9-i686-Linux/local/lib/python2.7/site-packages/sage/structure\n        /unique_representation.py Line: 1021\n        L: Body         Elapse:   145, Total:   0 genList prepared In: as_matrix_group Line: 1038\n            ---> __create_classical_realization__ In: lib/cubic_braid.py Line: 968\n            ---> __init__ In: lib/cubic_braid.py Line: 471\n            ---> __classcall__ In: /opt/sage/sage-6.9-i686-Linux/local/lib/python2.7/site-packages/sage/structure\n        /unique_representation.py Line: 1021\n        Cubic Braid group on 3 strands\n        sage: \n    \n\n    TESTS:\n\n        sage: C4 = CubicBraidGroup(4)\n        sage: TestSuite(C4).run()\n        sage: C5 = CubicBraidGroup(5)\n        sage: TestSuite(C5).run()\n        sage: C6 = CubicBraidGroup(6)\n        sage: TestSuite(C6).run()\n        sage: S3 = AssionGroupS(3)\n        sage: TestSuite(S3).run()\n        sage: S4 = AssionGroupS(4)\n        sage: TestSuite(S5).run()\n        sage: U3 = AssionGroupU(3)\n        sage: TestSuite(U3).run()\n        sage: U4 = AssionGroupU(4)\n        sage: TestSuite(U4).run()\n        sage: U5 = AssionGroupU(5)\n        sage: TestSuite(U5).run()\n\n    METHODS (implemented / overwriten here):\n\n        - as_classical_group(): type \n                   sage: print CubicBraidGroup_class.as_classical_group.__doc__\n        - as_matrix_group(): type \n                   sage: print CubicBraidGroup_class.as_matrix_group.__doc__\n        - as_refection_group(): type \n                   sage: print CubicBraidGroup_class.as_refection_group.__doc__\n        - as_permutation_group(): type \n                   sage: print CubicBraidGroup_class.as_permutation_group.__doc__\n        - pre_image_braid_group: type\n                   sage: print CubicBraidGroup_class.pre_image_braid_group.__doc__\n        - cubic_braid_subgroup(): type \n                   sage: print CubicBraidGroup_class.cubic_braid_subgroup.__doc__\n        - centralizing_element(): type \n                   sage: print CubicBraidGroup_class.centralizing_element.__doc__\n        - order(): type \n                   sage: print CubicBraidGroup_class.order.__doc__\n        - character_table(): type \n                   sage: print CubicBraidGroup_class.character_table.__doc__\n\n    AUTHOR\n\n      - Sebastian Oehms, Sept. 2016\n\n    REFERENCES:\n\n    - Coxeter, H.S.M: \"Factor groups of the braid groups, Proceedings of the Fourth Candian Mathematical Congress\n      (Vancover      1957), pp. 95-122\".\n    \n    - J. Assion: \"Einige endliche Faktorgruppen der Zopfgruppen\" (Math. Z., 163 (1978), 291-302) \n    "}︡{"stdout":"\n"}︡{"done":true}︡
︠17b539fb-85e3-442f-bd9c-d02422d066d2i︠
%md
## First steps

To definine the cubic braid group on 3 strand, for example, type:
︡a615ae87-beb6-4f75-a526-644fdd945cad︡{"done":true,"md":"## First steps\n\nTo definine the cubic braid group on 3 strand, for example, type:"}
︠8011cf84-8ac0-4665-a3b8-5ced1c222fa6s︠
C3 = CubicBraidGroup( 3 ); C3
︡f0aaeedc-17ef-484b-a606-2dd9030c9b57︡{"stdout":"Cubic Braid group on 3 strands"}︡{"stdout":"\n"}︡{"done":true}︡
︠543ea394-3fe7-4329-97cf-a6060fdeda5ei︠
%md
There are several ways to obtain the braid generators as variables: First using the pre defined names:
︡8c7d2e60-3f41-4cd0-a6db-cb389536daf8︡{"done":true,"md":"There are several ways to obtain the braid generators as variables: First using the pre defined names:"}
︠bd68bdd5-6180-47b0-bc9d-62febd990cbes︠
C3.inject_variables()
︡cc584f00-7229-4fef-b4bd-e2272bbd1d86︡{"stdout":"Defining c0, c1\n"}︡{"done":true}︡
︠1a89c5e8-25d9-43f1-94e5-614b7671b4d4i︠
%md
Second, if you like to use your own names it is possiblbe to include a generator declaration inside the group declaration in two ways (caution: sage-kernel needed, this does no work for a pure python kernel):
︡3b2be1a2-a4a6-4669-8b79-afe6ddea2d5d︡{"done":true,"md":"Second, if you like to use your own names it is possiblbe to include a generator declaration inside the group declaration in two ways (caution: sage-kernel needed, this does no work for a pure python kernel):"}
︠e3abc2a5-ae80-4522-842e-71475ace8a36s︠
C4.<c1, c2, c3> = CubicBraidGroup(4); print "Element of C4", c1*c2**2*c3
U4 = AssionGroupU(4, 'a, b, c' ); a, b, c = U4.gens(); print "Element of U4", a*b**2*c
︡658dacdf-d8b3-4add-9ee5-686d964b85cd︡{"stdout":"Element of C4"}︡{"stdout":" c1*c2^2*c3\n"}︡{"stdout":"Element of U4"}︡{"stdout":" a*b^2*c\n"}︡{"done":true}︡
︠eb27baf8-82e7-42e2-828c-0e5ec01edaa1i︠
%md
But, note:
︡58afef07-dc9d-4fe2-af10-f633d265d07d︡{"done":true,"md":"But, note:"}
︠9d85ec9a-bdf2-4b46-be97-4507d37ee44cs︠
S4 = AssionGroupS(4); x, y, z = S4.gens(); print "Element of S4", x*y**2*z
︡cabb9149-f5e0-4c0d-997c-c74d820cf8b3︡{"stdout":"Element of S4"}︡{"stdout":" s0*s1^2*s2\n"}︡{"done":true}︡
︠229c5a21-3801-4c6f-a958-78a0a7f1cdc8i︠
%md
## Classical realization

Now, lets define Coxeter's realization of the 3 strand cubic braid group:
︡962a8a92-7b7a-4ec7-81a3-e84644acc5df︡{"done":true,"md":"## Classical realization\n\nNow, lets define Coxeter's realization of the 3 strand cubic braid group:"}
︠21cf917a-d680-4fe3-8280-971737145d5es︠
C3Cl = C3.as_classical_group(); C3Cl
︡52a9a381-c630-4114-ad5b-6f0f7715461d︡{"stdout":"Subgroup of Unitary Group of degree 2 over Universal Cyclotomic Field with respect to hermitian form\n[-E(12)^7 + E(12)^11                  -1]\n[                 -1 -E(12)^7 + E(12)^11] generated by:\n([    E(3) E(12)^11]\n[       0        1], [       1        0]\n[E(12)^11     E(3)])\n"}︡{"done":true}︡
︠b249d628-c387-4f29-80fb-a52e16f84b58i︠
%md
You may apply any method implemented for groups and finitely presented resp. finitely generated matrix groups in sage to C3 resp. C3Cl, for instance to check if they are isomorphic:
︡b1e833bb-0570-427b-897d-832f97ce1fb4︡{"done":true,"md":"You may apply any method implemented for groups and finitely presented resp. finitely generated matrix groups in sage to C3 resp. C3Cl, for instance to check if they are isomorphic:"}
︠daa4db31-6438-4781-a2c3-c0a2611d0c65s︠
C3.is_isomorphic( C3Cl )
︡c500d612-d7b2-4797-a9d8-3c04a07d8458︡{"stdout":"True"}︡{"stdout":"\n"}︡{"done":true}︡
︠e7a51c75-801c-40a5-a75e-e1e386cbafcei︠
%md
To see which methods are availlable you may use the python 'dir' function. To see all methods containing the substring 'is_' in their names, for instance, type:
︡9b60270d-78c4-4887-8903-971d178ae117︡{"done":true,"md":"To see which methods are availlable you may use the python 'dir' function. To see all methods containing the substring 'is_' in their names, for instance, type:"}
︠1bd99b1b-625c-467d-8bdf-24dee9cbb951s︠
print 'Attributes of C3:\n', [ attrib for attrib in dir(C3) if attrib.find('is_') >= 0]
︡a87544d3-5697-4f69-b65d-fcebd0b4c207︡{"stdout":"Attributes of C3:\n['_interface_is_cached_', '_is_category_initialized', '_is_valid_homomorphism_', 'is_abelian', 'is_atomic_repr', 'is_coercion_cached', 'is_commutative', 'is_conversion_cached', 'is_empty', 'is_exact', 'is_finite', 'is_isomorphic', 'is_multiplicative', 'is_parent_of', 'is_subgroup']\n"}︡{"done":true}︡
︠a8e2cff5-92a2-4460-b061-c6bb21fe24c7i︠
%md
Restriction to substrings at the beginning or end works like this:
︡2c50655a-5a69-420d-8d8b-0c7196473af8︡{"done":true,"md":"Restriction to substrings at the beginning or end works like this:"}
︠222157b1-60f0-4ce3-8e91-a7bd8a5d32c0s︠
print 'Attributes of C3:\n', [ attrib for attrib in dir(C3) if attrib.startswith('as_') ], '\n'
print 'Attributes of C3:\n', [ attrib for attrib in dir(C3) if attrib.endswith('_group') ], '\n'
print 'Attributes of C3Cl:\n', [ attrib for attrib in dir(C3Cl) if attrib.startswith('as_') ], '\n'
print 'Attributes of C3Cl:\n', [ attrib for attrib in dir(C3Cl) if attrib.endswith('_group') ]
︡ad44f100-d0ca-4784-800a-9361f321b805︡{"stdout":"Attributes of C3:\n['as_classical_group', 'as_matrix_group', 'as_permutation_group', 'as_reflection_group'] \n\n"}︡{"stdout":"Attributes of C3:\n['_free_group', 'as_classical_group', 'as_matrix_group', 'as_permutation_group', 'as_reflection_group', 'free_group', 'pre_image_braid_group'] \n\n"}︡{"stdout":"Attributes of C3Cl:\n['as_matrix_group', 'as_permutation_group'] \n\n"}︡{"stdout":"Attributes of C3Cl:\n['as_matrix_group', 'as_permutation_group']\n"}︡{"done":true}︡
︠12f9164c-5a41-412c-a59c-363fc1c82502i︠
%md
In stead of the "startswith" query you can use the "TAB"-key functionality like with "bash", as well.



The above used method "as_classical_group" is a special method of the CubicBraidGroup class. It returns the realization of the cubic braid group as classical group. These are (in principal) symplectic groups over $GF(3)$ resp. unitary groups over $GF(4)$ in the case of Assion groups of type "S" and "U" respectively (realization of Assion) and subgroups of the unitary groups over  $\QQ$  adjoined with a primitive 12-th root of unity with respect to a certain hermitian form in the case of the ordinary cubic braid groups (Coxeters realization):
︡39797453-9172-4eb0-acde-e9dde08db0f1︡{"done":true,"md":"In stead of the \"startswith\" query you can use the \"TAB\"-key functionality like with \"bash\", as well.\n\n\n\nThe above used method \"as_classical_group\" is a special method of the CubicBraidGroup class. It returns the realization of the cubic braid group as classical group. These are (in principal) symplectic groups over $GF(3)$ resp. unitary groups over $GF(4)$ in the case of Assion groups of type \"S\" and \"U\" respectively (realization of Assion) and subgroups of the unitary groups over  $\\QQ$  adjoined with a primitive 12-th root of unity with respect to a certain hermitian form in the case of the ordinary cubic braid groups (Coxeters realization):"}
︠f6f135c0-4228-4ff6-9063-8d3b2ecf92b9s︠
S3 = AssionGroupS(3); print S3; print ""
S3Cl = S3.as_classical_group(); print S3Cl; print ""
U3 = AssionGroupU(3); print U3; print ""
U3Cl = U3.as_classical_group(); print U3Cl
︡3a587d6e-5dd0-477d-b412-1f9fcc586855︡{"stdout":"Assion group on 3 strands of type S"}︡{"stdout":"\n\n"}︡{"stdout":"Symplectic Group of degree 2 over Finite Field of size 3\n\n"}︡{"stdout":"Assion group on 3 strands of type U"}︡{"stdout":"\n\n"}︡{"stdout":"Subgroup of (The projective general unitary group of degree 3 over Finite Field of size 2) generated by [(1,7,6)(3,19,14)(4,15,10)(5,11,18)(12,16,20), (1,12,13)(2,15,19)(4,9,14)(5,18,8)(6,21,16)]\n"}︡{"done":true}︡
︠4cf7fa07-3295-4284-9d90-2795d5756f18i︠
%md
## Exceptions in Assions series

U3Cl is an exception to the statement above! It is not identical to the unitary group of degree 2. This exception occurs if the number of strands is zero mululo three in the case of Assion groups of type U resp. if the number of strands is even concerning the Assion groups of type S. But, since U3Cl is a subgroup of U4Cl (the unitary group of degree 3 over $GF(4)$ ) you may obtain it like this:
︡b8a87ca3-915c-4c64-827e-9c3f74d3649a︡{"done":true,"md":"## Exceptions in Assions series\n\nU3Cl is an exception to the statement above! It is not identical to the unitary group of degree 2. This exception occurs if the number of strands is zero mululo three in the case of Assion groups of type U resp. if the number of strands is even concerning the Assion groups of type S. But, since U3Cl is a subgroup of U4Cl (the unitary group of degree 3 over $GF(4)$ ) you may obtain it like this:"}
︠5096ce3e-3464-4d4c-83ea-19d65a3d5ec8s︠
U3Clemb = U3.as_classical_group( embedded = True); print U3Clemb; print ""
um1, um2 =U3Clemb.gens()

U4 = AssionGroupU(4)
U4Cl = U4.as_classical_group(); print U4Cl; print ""

print 'first generator in U4Cl?',  um1 in U4Cl
print 'second generator in U4Cl?', um2 in U4Cl
︡a5b289a6-a1bc-4be4-a12a-96488c612619︡{"stdout":"Matrix group over Finite Field in a of size 2^2 with 2 generators (\n[0 0 a]  [a + 1     a     a]\n[0 1 0]  [    a a + 1     a]\n[a 0 a], [    a     a a + 1]\n)\n\n"}︡{"stdout":"General Unitary Group of degree 3 over Finite Field in a of size 2^2\n\n"}︡{"stdout":"first generator in U4Cl? True\n"}︡{"stdout":"second generator in U4Cl? True\n"}︡{"done":true}︡
︠efd51a73-5e9d-40ed-a640-f9b9cb785defi︠
%md
Don't confuse about the difference with respect to the base field concerning GU(3,2) (size 2²) and PGU(3,2) (size 2) which is caused by non conform conventions inside sage.

### Description of the exceptions as centralizer

Assion described the exceptional cases of the groups $S(m)$ and $U(m)$ as centralizer groups of certain elements in the projective counterpart of the corresponding classical group. These elements can be obtained by the following method:
︡fdcb890d-5918-44a8-93df-51bf5e2931b2︡{"done":true,"md":"Don't confuse about the difference with respect to the base field concerning GU(3,2) (size 2²) and PGU(3,2) (size 2) which is caused by non conform conventions inside sage.\n\n### Description of the exceptions as centralizer\n\nAssion described the exceptional cases of the groups $S(m)$ and $U(m)$ as centralizer groups of certain elements in the projective counterpart of the corresponding classical group. These elements can be obtained by the following method:"}
︠25aba7ba-11df-466c-95e1-13f6af5cc701s︠
u3cent = U3.centralizing_element(); print "centalizing element (u3cent):\n%s\n" %( u3cent )
print "u3cent in U3Cl? %s" %( u3cent in U3Cl )
print "u3cent in U3Clemb? %s\n" %(u3cent in U3Clemb )

u3centP = U3.centralizing_element(projective = True ); print "projective centalizing element (u3centP):\n%s\n" %( u3centP )
print "u3centP in U3Cl? %s" %(u3centP in U3Cl)
print "u3centP in U3Clemb? %s\n" %(u3centP in U3Clemb)

PU3 = U3Cl.ambient_group(); print "Ambient Group of U3Cl (PU3):\n%s\n" %(PU3)
PU3cent = PU3.centralizer(u3centP); print "Centralizer of u3centP in PU3 (PU3cent):\n%s\n" %(PU3cent)

print "Check PU3cent == U3Cl: %s" %( U3Cl == PU3cent)
︡f6dcecd0-d20b-4c22-a93b-974f2e46a043︡{"stdout":"centalizing element (u3cent):\n[a + 1 a + 1     1]\n[a + 1     0     a]\n[    1     a     a]\n\n"}︡{"stdout":"u3cent in U3Cl? False\n"}︡{"stdout":"u3cent in U3Clemb? True\n\n"}︡{"stdout":"projective centalizing element (u3centP):\n(1,16)(2,9)(3,10)(4,19)(6,12)(7,20)(13,21)(14,15)\n\n"}︡{"stdout":"u3centP in U3Cl? True\n"}︡{"stdout":"u3centP in U3Clemb? False\n\n"}︡{"stdout":"Ambient Group of U3Cl (PU3):\nThe projective general unitary group of degree 3 over Finite Field of size 2\n\n"}︡{"stdout":"Centralizer of u3centP in PU3 (PU3cent):\nSubgroup of (The projective general unitary group of degree 3 over Finite Field of size 2) generated by [(2,3,4)(6,13,20)(7,12,21)(8,11,18)(9,10,19), (1,6,7)(3,14,19)(4,10,15)(5,18,11)(12,20,16), (1,16)(2,9)(3,10)(4,19)(6,12)(7,20)(13,21)(14,15)]\n\n"}︡{"stdout":"Check PU3cent == U3Cl: True\n"}︡{"done":true}︡
︠fdb268b5-18c7-448d-bb06-c32ef748a5c3i︠
%md
## Conversion maps

Observe, that the cubic braid groups do not differ from the corresponding Assion groups in terms of isomorphism as long as the number of strand is less than five:
︡112811d3-cea8-4bdc-a528-f9ef9d9ddd4e︡{"done":true,"md":"## Conversion maps\n\nObserve, that the cubic braid groups do not differ from the corresponding Assion groups in terms of isomorphism as long as the number of strand is less than five:"}
︠de933577-e589-4da5-93b9-e45d621572b3s︠
print 'C3 isomorphic to S3?', C3.is_isomorphic(S3)
print 'C3 isomorphic to U3?', C3.is_isomorphic(U3)
print 'C3 isomorphic to S3Cl?', C3.is_isomorphic(S3Cl)
print 'C3 isomorphic to U3Cl?', C3.is_isomorphic(U3Cl)
print 'C3 isomorphic to U3Clemb?', C3.is_isomorphic(U3Clemb)
︡22e4cf9b-0e55-4508-a5b1-761b506de28e︡{"stdout":"C3 isomorphic to S3? "}︡{"stdout":"True\n"}︡{"stdout":"C3 isomorphic to U3? "}︡{"stdout":"True\n"}︡{"stdout":"C3 isomorphic to S3Cl? True\n"}︡{"stdout":"C3 isomorphic to U3Cl? True\n"}︡{"stdout":"C3 isomorphic to U3Clemb? True\n"}︡{"done":true}︡
︠32a212b0-3d5f-4d15-b06d-fbc61b90d8d5i︠
%md
These isomorphisms are canonical in the case of S3 and U3 since all these groups are defined as finitely presented groups with identical number of generators and according relations:
︡b8826d4b-53e7-4f03-9db1-38e97d3e4158︡{"done":true,"md":"These isomorphisms are canonical in the case of S3 and U3 since all these groups are defined as finitely presented groups with identical number of generators and according relations:"}
︠7e72dab8-4126-4292-b823-ca7195df0adfs︠
print 'Relations of C3:\n%s\n'%( list(C3.relations()) )
print 'Relations of S3:\n%s\n'%( list(S3.relations()) )
︡46e9878b-74d0-4f7d-a757-6a61e4269800︡{"stdout":"Relations of C3:\n[c0*c1*c0*c1^-1*c0^-1*c1^-1, c0^3, c1^3]\n\n"}︡{"stdout":"Relations of S3:\n[s0*s1*s0*s1^-1*s0^-1*s1^-1, s0^3, s1^3]\n\n"}︡{"done":true}︡
︠9982ef44-76e7-4e94-9f01-2518caa6db38i︠
%md
In the other cases the maps are realized as conversion maps, that is:
︡f4afda44-420c-4924-a8ed-b25dc1aef14d︡{"done":true,"md":"In the other cases the maps are realized as conversion maps, that is:"}
︠b54694c4-ab4a-4a10-bbbd-b0b0d6bd4d3fs︠
C3.inject_variables(); element = c0*c1**2; image_element = C3Cl(element)
print 'Image of %s in C3Cl:\n%s\n' %(element, image_element)
U3.inject_variables(); element = u0*u1**2; image_element = U3Cl(element)
print 'Image of %s in U3Cl:\n%s\n' %(element, image_element)
image_element = U3Clemb(element)
print 'Image of %s in U3Clemb:\n%s\n' %(element, image_element)
︡5c91d1b3-697e-4dbc-a53c-3d069f23624a︡{"stdout":"Defining c0, c1\n"}︡{"stdout":"Image of c0*c1^2 in C3Cl:\n[ -E(3)^2  E(12)^7]\n[-E(12)^7   E(3)^2]\n\n"}︡{"stdout":"Defining u0, u1\n"}︡{"stdout":"Image of u0*u1^2 in U3Cl:\n(1,7,16,20)(2,19,9,4)(3,15,10,14)(5,11)(6,13,12,21)(8,18)\n\n"}︡{"stdout":"Image of u0*u1^2 in U3Clemb:\n[    1     1 a + 1]\n[a + 1     a a + 1]\n[    a     0     a]\n\n"}︡{"done":true}︡
︠22bc4bfa-f98c-45b9-ac2c-155b29193e02i︠
%md
You may also convert in the opposite direction:
︡13f99a22-0283-4f05-bb53-5948b4b8cde3︡{"done":true,"md":"You may also convert in the opposite direction:"}
︠3c249409-9422-43a4-b759-45724c4c0122s︠
elements = list(S3Cl.some_elements())
image_elements = [ S3(element) for element in elements ]

print 'Images of\n\n%s\n\nand\n\n%s\n\nin S3:\n\n%s\n' %(elements[0], elements[1], image_elements)
︡59b04c62-9e8e-41e9-92f0-f696ab38cef9︡{"stdout":"Images of\n\n[1 1]\n[0 1]\n\nand\n\n[0 1]\n[2 0]\n\nin S3:\n\n[s1, s0*s1*s0]\n\n"}︡{"done":true}︡
︠13a38fb5-53fc-445b-9a7f-df1660756d84i︠
%md
## Preimages in the Artin braid group

For each element of a cubic braid group you can define a preimage in the braid group as instance of the element class of the braid group class:
︡e5486bc7-90fe-445b-9204-3d47b003ac02︡{"done":true,"md":"## Preimages in the Artin braid group\n\nFor each element of a cubic braid group you can define a preimage in the braid group as instance of the element class of the braid group class:"}
︠17816e66-1ee2-4b6e-98cb-691aa7cbd1a4s︠
braid_elements = [element.braid() for element in image_elements ]
print 'Braid preimages of\n%s\nand\n%s:\n\n%s\n' %(elements[0], elements[1], braid_elements)
type(braid_elements[0])
jones_polynomial = [element.jones_polynomial() for element in braid_elements ]
print 'Coresponding Jones polynomials:\n%s\n' %(jones_polynomial)
burau_matrix = braid_elements[1].burau_matrix()
print 'Burau matrix to second braid preimage:\n%s' %(burau_matrix)
︡c9ac9a8d-4c83-42eb-8fd9-98a3d674421b︡{"stdout":"Braid preimages of\n[1 1]\n[0 1]\nand\n[0 1]\n[2 0]:\n\n[s1, s0*s1*s0]\n\n"}︡{"stdout":"<class 'lib.local_braid.local_BraidGroup_class_with_category.element_class'>\n"}︡{"stdout":"Coresponding Jones polynomials:\n[-sqrt(t) - 1/sqrt(t), -t^(5/2) - sqrt(t)]\n\n"}︡{"stdout":"Burau matrix to second braid preimage:\n[  1 - t t - t^2     t^2]\n[  1 - t       t       0]\n[      1       0       0]\n"}︡{"done":true}︡
︠3bd86eec-dce2-4a40-9f9a-6d0633a99ee2i︠
%md
## Burau matrices  for the cubic braid groups

You can calculate the burau matrix correspondig to elements of the cubic braid groups, as well. By default you will get it as matrix over $\QQ$ adjoint with a third root of unity (zeta3):
︡2ac18062-3dcb-4d2f-8382-c60056cbd730︡{"done":true,"md":"## Burau matrices  for the cubic braid groups\n\nYou can calculate the burau matrix correspondig to elements of the cubic braid groups, as well. By default you will get it as matrix over $\\QQ$ adjoint with a third root of unity (zeta3):"}
︠74ce0d1a-31cc-464b-93b6-7b7565e4633fs︠
elem = image_elements[1]
print "Burau:\n%s" %(elem.burau_matrix())
︡8e4dbdd7-2b64-457d-9e7e-adb7d3085687︡{"stdout":"Burau:\n[   -zeta3         1     zeta3]\n[   -zeta3 zeta3 + 1         0]\n[        1         0         0]"}︡{"stdout":"\n"}︡{"done":true}︡
︠95dc595d-ee3f-4bd0-891c-e25bf76b4ebci︠
%md
Using the additional options of this method, you can construct representations in finite matrix groups, as well:
︡98b3876b-2d12-4b17-8af6-af0b880ff533︡{"done":true,"md":"Using the additional options of this method, you can construct representations in finite matrix groups, as well:"}
︠f3301db7-f3cf-45e4-812c-786215fa79fbs︠
bur_mat = elem.burau_matrix(characteristic = 5)
print "Burau in characteristic 5:\n%s\nbase_ring: %s" %(bur_mat, bur_mat.base_ring())
︡27c2186c-1248-4e5f-84a7-9c5080780276︡{"stdout":"Burau in characteristic 5:\n[2*rI + 2        1 3*rI + 3]\n[2*rI + 2 3*rI + 4        0]\n[       1        0        0]\nbase_ring: Finite Field in rI of size 5^2\n"}︡{"done":true}︡
︠fdf7ba0b-4e9b-4c3f-bf69-2c77cef66effi︠
%md
To see all possible options type (but again, note that carriage return is ignored in the sage worksheet. To see it better use jupyter notebook or command line):
︡6d9ff5f4-5e59-46be-acde-bc6ef8b0ee1b︡{"done":true,"md":"To see all possible options type (but again, note that carriage return is ignored in the sage worksheet. To see it better use jupyter notebook or command line):"}
︠c4e72dea-7256-4466-b981-47b6c330cc14s︠
print CubicBraidElement.burau_matrix.__doc__
︡31097e9a-a3d3-4022-8603-b6ea19f78ba2︡{"stdout":"\n        Return the Burau matrix of the cubic braid coset. \n\n        If you don't see this well formatted type \n\n        sage: print CubicBraidElement.burau_matrix.__doc_\n\n        This method uses the same method belonging to the Braid class, but reduces the parameter to a primitive six \n        root of unity, respectivly an element vanishing on the polynomial $x^2-x+1$\n\n        INPUT: (all parameters are optional by keyword )\n\n        - \"rootBur\": six root of unity in some field (default six root of unity over $\\QQ$)\n        - \"Domain\":  base_ring for the burau matrix (default is Cyclotomic Field of order 3 and degree 2, resp. the \n                     domain of rootBur if given)\n        - \"reduced\": boolean (default: False); whether to return the reduced or unreduced Burau representation \n                     (see Braid class )\n        - \"characteristic\": integer giving the characteristic of the domain (default is 0 or the characteristic of \n                     the doamain if given) \n        - \"version\":  values: \n                      'unitary': gives the unitary form according to Squier (see Braid._unitary_burau_matrix_() )\n                      'default': the method behaves like the original one of the Braid -class\n                      any value else: gives the reduced form given on wikipedia\n     \n\n        OUTPUT:\n\n            The Burau matrix of the cubic braid coset with entries in the domain given by the options\n         \n            If you need the values of the reconstructed keywords \"rootBur\", \"Domain\" or \"characteristic\" use the internal \n            version _burau_matrix_ of this method\n\n        RAISE:\n\n           - ValueError: 'characteristic must be in integer'\n\n           - ValueError: 'characteristic must be a prime'\n\n           - ValueError: 'characteristic of Domain does not match given characteristic'\n\n           - ValueError: 'rootBur must belong to a domain containing 1'\n\n           - ValueError: 'rootBur must vanish on $x^2-x+1$ default case        \n\n           - ValueError: 'rootBur must vanish on $x^4-x^2+1$ in case of call with version = 'unitary'\n        \n\n\n        EXAMPLES::\n\n            sage: C3.<c1, c2> = CubicBraidGroup(3)\n            sage: ele1 = c1*c2*c1\n            sage: BurauTest = ele1.burau_matrix(); print BurauTest\n            [   -zeta3         1     zeta3]\n            [   -zeta3 zeta3 + 1         0]\n            [        1         0         0]\n            sage: BurauTest.base_ring()\n            Cyclotomic Field of order 3 and degree 2\n            sage:\n            sage: BurauTest = ele1.burau_matrix( characteristic = 0 ); print BurauTest\n            [   -zeta3         1     zeta3]\n            [   -zeta3 zeta3 + 1         0]\n            [        1         0         0]\n            sage: BurauTest.base_ring()\n            Cyclotomic Field of order 3 and degree 2\n            sage:\n            sage: BurauTest = ele1.burau_matrix( Domain = QQ ); print BurauTest\n            Warning: Domain extended to splitting field of tT^2 - tT + 1\n            [-rI + 1       1  rI - 1]\n            [-rI + 1      rI       0]\n            [      1       0       0]\n            sage: BurauTest.base_ring()\n            Number Field in rI with defining polynomial tT^2 - tT + 1\n            sage:\n            sage: BurauTest = ele1.burau_matrix( Domain = QQ[I, sqrt(3)] ); print BurauTest\n            [ 1/2*sqrt3*I + 1/2                  1 -1/2*sqrt3*I - 1/2]\n            [ 1/2*sqrt3*I + 1/2 -1/2*sqrt3*I + 1/2                  0]\n            [                 1                  0                  0]\n            sage: BurauTest.base_ring()\n            Number Field in I with defining polynomial x^2 + 1 over its base field\n            sage:\n            sage: BurauTest = ele1.burau_matrix( characteristic = 7 ); print BurauTest\n            [3 1 4]\n            [3 5 0]\n            [1 0 0]\n            sage: BurauTest.base_ring()\n            Finite Field of size 7\n            sage:\n            sage: BurauTest = ele1.burau_matrix( characteristic = 2 ); print BurauTest\n            [rI + 1      1 rI + 1]\n            [rI + 1     rI      0]\n            [     1      0      0]\n            sage: BurauTest.base_ring()\n            Finite Field in rI of size 2^2\n            sage:\n            sage: \n            sage: F4.<r64> = GF(4)\n            sage: BurauTest = ele1.burau_matrix( rootBur=r64 ); print BurauTest\n            [r64 + 1       1 r64 + 1]\n            [r64 + 1     r64       0]\n            [      1       0       0]\n            sage: BurauTest.base_ring()\n            Finite Field in r64 of size 2^2\n            sage: \n            sage: BurauTest = ele1.burau_matrix( Domain = GF(5) ); print BurauTest\n            Warning: Domain extended to splitting field of tT^2 + 4*tT + 1\n            [2*rI + 2        1 3*rI + 3]\n            [2*rI + 2 3*rI + 4        0]\n            [       1        0        0]\n            sage: BurauTest.base_ring()\n            Finite Field in rI of size 5^2\n            sage:\n            sage: BurauTest = ele1.burau_matrix( version = 'unitary' ); print BurauTest\n            [        0 -zeta12^3]\n            [-zeta12^3         0]\n            sage: BurauTest.base_ring()\n            Cyclotomic Field of order 12 and degree 4\n            sage: \n            sage: BurauTest = ele1.burau_matrix( Domain = QQ[I, sqrt(3)], version = 'unitary' ); print BurauTest\n            [ 0 -I]\n            [-I  0]\n            sage: BurauTest.base_ring()\n            Number Field in I with defining polynomial x^2 + 1 over its base field\n\n        AUTHOR:\n\n          - Sebastian Oehms, Sept. 2016\n\n\n        REFERENCES:\n\n           - :wikipedia: \"Burau_representation\"\n\n\n        for more inormation type\n        sage: print Braid.burau_matrix.__doc__\n        sage: print local_Braid.burau_matrix.__doc__\n        sage: print local_Braid.__burau_matrix_wikipedia__.__doc__\n        sage: print local_Braid.__burau_matrix_unitary__.__doc__\n\n        "}︡{"stdout":"\n"}︡{"done":true}︡
︠efdd3b67-d8e0-4cb8-bc48-ada1ec523c05i︠
%md
## Other matrix group realizations via the Burau representation

If you want to create the image of the Burau representation as as matrix group together with the corresponding group homorphism you just need to type, for instance:
︡59a314d8-394f-438f-af9f-17955eab3653︡{"done":true,"md":"## Other matrix group realizations via the Burau representation\n\nIf you want to create the image of the Burau representation as as matrix group together with the corresponding group homorphism you just need to type, for instance:"}
︠0f36fcf6-28d0-4f65-b8a7-0a623a9baa4ds︠
C3c7 = C3.as_matrix_group( Domain = GF(7) ); C3c7
︡4c915b1d-2dda-4813-b0fb-9da7717b24b9︡{"stdout":"Matrix group over Finite Field of size 7 with 2 generators (\n[3 5 0]  [1 0 0]\n[1 0 0]  [0 3 5]\n[0 0 1], [0 1 0]\n)"}︡{"stdout":"\n"}︡{"done":true}︡
︠38b11b50-31ed-41fc-95b3-72ff2dbc0361i︠
%md
Conversion maps are availlable as in the case of the classical groups:
︡0a6f24e7-8fbf-4d18-90cb-a19ca2e798c8︡{"done":true,"md":"Conversion maps are availlable as in the case of the classical groups:"}
︠ae73fbff-2150-4516-adfc-24eadc0d47bfs︠
c1, c2 = C3.gens(); elemC3 = c1*c2
elemC3c7 = C3c7( elemC3 ); print "elemC3c7:\n", elemC3c7
elemC3back = C3( elemC3c7 ); print "elemC3back:\n", elemC3back
print "Check: ", elemC3back == elemC3
︡24ff755a-188d-4b08-b3ba-5a6aa2bc30f1︡{"stdout":"elemC3c7:\n[3 1 4]\n[1 0 0]\n[0 1 0]\n"}︡{"stdout":"elemC3back:\nc0*c1\n"}︡{"stdout":"Check:  True\n"}︡{"done":true}︡
︠fe7c23e3-f651-4f7d-a5c4-c595dda77de8i︠
%md
Of course, the map backwards is a group homomorphism only if the representation is faithfull. In general this conversion map is a section.
Further, note that the Burau representation does factor through the relations of Assion, just for certain characteristic.

## Realization as complex reflection groups

A third kind of realization of the cubic braid groups leads to complex reflection groups. This realization is availlable starting with sage version 7.2 if in addition gap3 with the CHEVIE package is installed. In this case the complex reflection group is obtained by:
︡ae78df87-4ec7-403a-82b8-bf2e58b7d81d︡{"done":true,"md":"Of course, the map backwards is a group homomorphism only if the representation is faithfull. In general this conversion map is a section.\nFurther, note that the Burau representation does factor through the relations of Assion, just for certain characteristic.\n\n## Realization as complex reflection groups\n\nA third kind of realization of the cubic braid groups leads to complex reflection groups. This realization is availlable starting wirh sage version 7.2 if in addition gap3 with the CHEVIE package is installed. In this case the complex reflection group is obtained by:"}
︠4acad579-617c-4ef3-85e4-1e2714324631s︠

R3 = C3.as_reflection_group(); R3
︡0db32261-5b9e-48e9-a468-563509403294︡{"stdout":"Irreducible complex reflection group of rank 2 and type ST4"}︡{"stdout":"\n"}︡{"done":true}︡
︠3df3f28a-61bb-4c70-9128-3c85f313f9f4i︠
%md
All methods implemented for the IrreduclibeComplexReflectionGroup class can be used for R3, for example:
︡68e95512-ce14-40b8-9b1f-36453e3c07e7︡{"done":true,"md":"All methods implemented for the IrreduclibeComplexReflectionGroup class can be used for R3, for example:"}
︠fc26f359-a8df-430d-8bd8-f4f7ab5eb982s︠
ctmat       = R3.cartan_matrix()
print "Cartan matrix corresponding to %s:\n%s\n" %(C3, ctmat)
simproots   = R3.simple_roots()
print "simple roots corresponding to %s:\n%s\n" %(C3, simproots)
reflhplanes = R3.reflection_hyperplanes()
print "reflection hyperplanes corresponding to %s:\n%s\n" %(C3, reflhplanes)
coxele      = R3.coxeter_element()
print "Coxeter element corresponding to %s:\n%s" %(C3, coxele)
︡70ed2d41-ce66-42c4-a87f-e2ecae966e2d︡{"stdout":"Cartan matrix corresponding to Cubic Braid group on 3 strands:\n[-2*E(3) - E(3)^2           E(3)^2]\n[         -E(3)^2 -2*E(3) - E(3)^2]\n\n"}︡{"stdout":"simple roots corresponding to Cubic Braid group on 3 strands:\nFinite family {1: (0, -2*E(3) - E(3)^2), 2: (2*E(3)^2, E(3)^2)}\n\n"}︡{"stdout":"reflection hyperplanes corresponding to Cubic Braid group on 3 strands:\nFinite family {1: Vector space of degree 2 and dimension 1 over Universal Cyclotomic Field\nBasis matrix:\n[1 0], 2: Vector space of degree 2 and dimension 1 over Universal Cyclotomic Field\nBasis matrix:\n[ 1 -1], 3: Vector space of degree 2 and dimension 1 over Universal Cyclotomic Field\nBasis matrix:\n[    1 -E(3)], 4: Vector space of degree 2 and dimension 1 over Universal Cyclotomic Field\nBasis matrix:\n[      1 -E(3)^2]}\n\n"}︡{"stdout":"Coxeter element corresponding to Cubic Braid group on 3 strands:\n(1,7,6,12,23,20)(2,8,17,24,9,5)(3,16,10,19,15,21)(4,14,11,22,18,13)\n"}︡{"done":true}︡
︠669aebe3-531e-4811-b936-4ee10d2eba70i︠
%md
Elements in R3 may be interpreted as element of the cubic braid group or the classical realization via conversion:
︡89105dff-59ae-46f3-901e-0df65e7a3eb1︡{"done":true,"md":"Elements in R3 may be interpreted as element of the cubic braid group or the classical realization via conversion:"}
︠4a5b4ba7-320d-43b0-9888-c23b675d83a6s︠

coxeleC3   = C3(coxele);   print "Coxeter element as element of %s:\n%s\n" %(C3,   coxeleC3)
coxeleC3Cl = C3Cl(coxele); print "Coxeter element as element of the classical group corresponding to the %s:\n%s\n" %(C3, coxeleC3Cl)
︡7c39df28-2fac-4220-821f-63c2420b3110︡{"stdout":"Coxeter element as element of Cubic Braid group on 3 strands:\nc0*c1\n\n"}︡{"stdout":"Coxeter element as element of the classical group corresponding to the Cubic Braid group on 3 strands:\n[       0     E(4)]\n[E(12)^11     E(3)]\n\n"}︡{"done":true}︡
︠c01e2abc-f85e-4117-bfa3-ba2e145c54c9i︠
%md
Conversion backwards is posible, as well:
︡7b4a8496-beda-4667-8a37-f5097d1ad608︡{"done":true,"md":"Conversion backwards is posible, as well:"}
︠9e148d1f-d81f-4d84-a345-2d0b7040f2fes︠
c1, c2 = C3.gens()
element = c1*c2/c1/c2; elementcl = C3Cl(element) 
image = R3(element);   print "Image of %s in %s:\n%s\n" %(element,   R3, image)
image = R3(elementcl); print "Image of \n%s\nin %s:\n%s\n" %(elementcl, R3, image)
︡85baa74b-a277-407d-8632-c445f34fd52a︡{"stdout":"Image of c0*c1*c0^-1*c1^-1 in Irreducible complex reflection group of rank 2 and type ST4:\n(1,15,12,16)(2,18,24,14)(3,17,19,5)(4,20,22,6)(7,9,23,8)(10,11,21,13)\n\n"}︡{"stdout":"Image of \n[     E(3)  E(12)^11]\n[-E(12)^11     -E(3)]\nin Irreducible complex reflection group of rank 2 and type ST4:\n(1,15,12,16)(2,18,24,14)(3,17,19,5)(4,20,22,6)(7,9,23,8)(10,11,21,13)\n\n"}︡{"done":true}︡
︠56f3dbf8-61a3-4a2e-89b7-f4c221ddeee1i︠
%md
The realization as reflection group allows another realization as matrix group beeing compatible to the corresponding root system. A method for this prurpose has been added to the IrreducibleComplexReflectionGroup_class inside the CubicBraidGroup_class:
︡f245b1c9-77fd-4e4e-bf86-5a0e15bd1efb︡{"done":true,"md":"The realization as reflection group allows another relaization as matrix group beeing compatible to the corresponding root system. A method for this prurpose has been added to the IrreducibleComplexReflectionGroup_class inside the CubicBraidGroup_class:"}
︠ad80bdec-7db0-4bc5-bcc4-a7ed2a44510cs︠
R4 = C4.as_reflection_group(); R4Cl = R4.as_matrix_group(); R4Cl
︡c72cd0cf-3647-4dd0-9148-c42097ec0d3c︡{"stdout":"Subgroup of General Unitary Group of degree 3 over Universal Cyclotomic Field generated by:\n([   1    0    0]\n[   0    1    0]\n[   0    0 E(3)], [-1/3*E(3) - 2/3*E(3)^2  2/3*E(3) + 1/3*E(3)^2  2/3*E(3) + 1/3*E(3)^2]\n[ 2/3*E(3) + 1/3*E(3)^2 -1/3*E(3) - 2/3*E(3)^2  2/3*E(3) + 1/3*E(3)^2]\n[ 2/3*E(3) + 1/3*E(3)^2  2/3*E(3) + 1/3*E(3)^2 -1/3*E(3) - 2/3*E(3)^2], [   1    0    0]\n[   0 E(3)    0]\n[   0    0    1])"}︡{"stdout":"\n"}︡{"done":true}︡
︠162f4059-1604-4322-8fd7-0acf5077fa68i︠
%md
But note, that even in the case where this matrix group is a subgroup of a unitary group, this realization is different from the classical group realization. Even the respective ambient groups are different, since they are defined with respect to different hermitian forms:
︡3e0f2a61-e90c-4af9-899c-ce0e47f058d5︡{"done":true,"md":"But note, that even in the case where this matrix group is a subgroup of a general linear group, this realization is different from the classical group realization. Even the respective ambient groups are different, since they are defined with respect to different hermitian forms:"}
︠68bd8b57-f74f-4d30-984c-fbaf08a803c3s︠
C4Cl = C4.as_classical_group()

print "ambient group of C4Cl:\n", C4Cl.ambient(); print ""
print "ambient group of R4Cl:\n", R4Cl.ambient(); print ""
print "hermitian Form of ambient group of R4Cl:\n", R4Cl.ambient().invariant_bilinear_form()
︡c55d6b0c-e4d4-4e5f-829d-2b323920cae1︡{"stdout":"ambient group of C4Cl:\nUnitary Group of degree 3 over Universal Cyclotomic Field with respect to hermitian form\n[-E(12)^7 + E(12)^11                  -1                   0]\n[                 -1 -E(12)^7 + E(12)^11                  -1]\n[                  0                  -1 -E(12)^7 + E(12)^11]\n\n"}︡{"stdout":"ambient group of R4Cl:\nGeneral Unitary Group of degree 3 over Universal Cyclotomic Field\n\n"}︡{"stdout":"hermitian Form of ambient group of R4Cl:\n[1 0 0]\n[0 1 0]\n[0 0 1]\n"}︡{"done":true}︡
︠363bec1b-4e4f-47d7-a0ce-714397616b34i︠
%md
## Realization as permutation groups

A third kind of realization of the cubic braid groups is that as permutation groups. This realization is in sage available for all finetely presented groups via the gap interface. In addition you will get coercion maps here, as well and a permutation group constructed with respect to the classical realization. This is the default in the call:
︡7c6154f1-9f4a-46d7-bdd3-c8ad2794e7ea︡{"done":true,"md":"## Realization as permutation groups\n\nA third kind of realization of the cubic braid groups is that as permutation groups. This realization is in sage available for all finetely presented groups via the gap interface. In addition you will get coercion maps here, as well and a permutation group constructed with respect to the classical realization. This is the default in the call:"}
︠043f7fcb-811f-4c46-a2cd-5e6a80368ed0s︠
C3.as_permutation_group()
︡b674d8f8-7b3f-4f8a-8cf1-a29255b5bf69︡{"stdout":"Subgroup of (Symmetric group of order 8! as a permutation group) generated by [(2,3,5)(4,6,8), (1,2,4)(5,7,6)]"}︡{"stdout":"\n"}︡{"done":true}︡
︠d09eee40-4291-4a96-ae7c-826c0fe6382ei︠
%md
To obtain the permutation group calculated for the finitely presented group you must type:
︡462dc79e-4946-4d5f-b1fd-8b58c351941d︡{"done":true,"md":"To obtain the permutation group calculated for the finitely presented group you must type:"}
︠334a292c-79b1-45ad-9fbb-1910ed9468d8s︠
C3.as_permutation_group( native = True )
︡8a3b0ca3-5dc6-422d-bcac-2bba19b4c267︡{"stdout":"Subgroup of (Symmetric group of order 8! as a permutation group) generated by [(2,4,5)(3,6,7), (1,2,3)(5,8,6)]"}︡{"stdout":"\n"}︡{"done":true}︡
︠9389692e-a54f-4e62-8fe2-22145c8388ebi︠
%md

## Other useful methods

In principal you can use all gap functions being available for these types of groups and being implemented via the gap interface of sage. Use the online help (\"print dir(C3)\" for example) as shown above to see them all. Here are some examples:
︡a6d4ffa5-a081-4734-aace-1bde2d24f14a︡{"done":true,"md":"\n## Other useful methods\n\nIn principal you can use all gap functions being available for these types of groups and being implemented via the gap interface of sage. Use the online help (\\\"print dir(C3)\\\" for example) as shown above to see them all. Here are some examples:"}
︠2bf1c4cb-8cd7-446f-8caa-fe0f89e678ees︠
S3.character_table()

︡897e9145-e89a-4a59-804f-3fca07196265︡{"stdout":"[         1          1          1          1          1          1          1]\n[         1 -zeta3 - 1      zeta3          1      zeta3 -zeta3 - 1          1]\n[         1      zeta3 -zeta3 - 1          1 -zeta3 - 1      zeta3          1]\n[         2         -1         -1         -2          1          1          0]\n[         2     -zeta3  zeta3 + 1         -2 -zeta3 - 1      zeta3          0]\n[         2  zeta3 + 1     -zeta3         -2      zeta3 -zeta3 - 1          0]\n[         3          0          0          3          0          0         -1]"}︡{"stdout":"\n"}︡{"done":true}︡
︠12d9ca29-fe7e-451f-86f1-95496d821ed3sr︠
U7 = AssionGroupU( 7 ); print "Order of U7:", U7.order()
︡774e3490-d199-4959-a8a7-8c30cd7c58b8︡
︠750fa09a-2740-4655-ab48-54e14130269es︠
conCls1s2 = S4.conjugacy_class( x*y**2*z ); conCls1s2
︡49987b06-2cde-4449-9772-d67a2c3d1e61︡{"stdout":"Conjugacy class of s0*s1^2*s2 in Assion group on 4 strands of type S\n"}︡{"done":true}︡
︠2251b885-48b8-412b-ba70-5ba936e9a3d2is︠
︡5f63aedc-4f9f-4b48-9cd7-4ea99c3ace49︡{"done":true}︡
︠fb9583e5-1daa-440a-9e86-108efa133178s︠

︡7c61ed51-2be6-4426-979f-609d7d942406︡{"done":true}︡









